@@ -1,12 +1,12 @@
 package Tangerine;
-$Tangerine::VERSION = '0.19';
+$Tangerine::VERSION = '0.20';
 # ABSTRACT: Examine perl files and report dependency metadata
 use 5.010;
 use strict;
 use warnings;
 use utf8;
 use PPI;
-use List::MoreUtils qw(none);
+use List::Util 1.33 qw(any none);
 use Scalar::Util qw(blessed);
 use Tangerine::Hook;
 use Tangerine::Occurence;
@@ -37,9 +37,9 @@ sub package { accessor _package => @_ }
 sub compile { accessor _compile => @_ }
 sub runtime { accessor _runtime => @_ }
 # For pre-0.15 compatibility
-sub provides { accessor _package => @_ }
-sub requires { accessor _runtime => @_ }
-sub uses { accessor _compile => @_ }
+*provides = \&package;
+*requires = \&runtime;
+*uses = \&compile;
 
 sub run {
     my $self = shift;
@@ -54,8 +54,11 @@ sub run {
     for my $type (qw(package compile runtime)) {
         for my $hname (@{$self->{_hooks}->{$type}}) {
             my $hook = "Tangerine::hook::$hname";
-            eval "require $hook";
-            push @hooks, $hook->new(type => $type);
+            if (eval "require $hook; 1") {
+                push @hooks, $hook->new(type => $type);
+            } else {
+                warn "Couldn't load the tangerine hook `${hname}'!";
+            }
         }
     }
     @hooks = grep {
@@ -78,8 +81,9 @@ sub run {
         for my $hook (@hooks) {
             if (my $data = $hook->run($children)) {
                 my $modules = $data->modules;
+                undef %$modules if any { $_ eq '->' } keys %$modules;
                 for my $k (keys %$modules) {
-                    if ($k !~ m/^[a-z_][a-z0-9_]*(::[a-z0-9_]+)*(::)?$/io ||
+                    if ($k !~ m/^[a-z_][a-z0-9_]*(?:::[a-z0-9_]+)*(?:::)?$/io ||
                         $k =~ m/^__[A-Z]+__$/o) {
                         delete $modules->{$k};
                         next
@@ -233,7 +237,7 @@ Petr Šabata <contyk@redhat.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015 Petr Šabata
+Copyright (c) 2014-2016 Petr Šabata
 
 See LICENSE for licensing details.
 
