@@ -1,10 +1,13 @@
 package Tangerine::Utils;
-$Tangerine::Utils::VERSION = '0.19';
+$Tangerine::Utils::VERSION = '0.20';
+use 5.010;
 use strict;
 use warnings;
+use version 0.77;
 use Exporter 'import';
-use List::MoreUtils qw(apply);
-our @EXPORT_OK = qw(accessor addoccurence stripquotelike);
+our @EXPORT_OK = qw(accessor addoccurence stripquotelike $vre);
+
+our $vre = qr/^($version::LAX)$/o;
 
 sub accessor {
     # TODO: This needs checks
@@ -13,9 +16,9 @@ sub accessor {
 
 sub stripquotelike {
     my @filtered = map {
-            if (/^('|").*$/o) {
+            if (/^(?:'|").*$/o) {
                 substr $_, 1, -1
-            } elsif (/^(\(|\[|\{).*$/so) {
+            } elsif (/^(?:\(|\[|\{).*$/so) {
                 stripquotelike(split /,|=>/so, substr $_, 1, -1)
             } elsif (/^qq?\s*[^\w](.*)[^\w]$/so) {
                 $1
@@ -25,10 +28,9 @@ sub stripquotelike {
                 $_
             }
         } grep {
-            1 if !/^(,|=>|;|)$/so
-        } apply {
-            s/^\s+|\s+$//sgo;
-            $_
+            1 if !/^(?:,|=>|;|)$/so
+        } map {
+            s/^\s+|\s+$//sgor
         } @_;
     return wantarray ? @filtered : $filtered[0];
 }
@@ -89,7 +91,7 @@ Petr Šabata <contyk@redhat.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015 Petr Šabata
+Copyright (c) 2014-2016 Petr Šabata
 
 See LICENSE for licensing details.
 
