@@ -1,19 +1,19 @@
 package Tangerine::hook::if;
-$Tangerine::hook::if::VERSION = '0.19';
+$Tangerine::hook::if::VERSION = '0.20';
 use 5.010;
 use strict;
 use warnings;
 use parent 'Tangerine::Hook';
-use List::MoreUtils qw(any);
+use List::Util 1.33 qw(any);
 use Tangerine::HookData;
-use Tangerine::Utils qw(stripquotelike);
+use Tangerine::Utils qw(stripquotelike $vre);
 
 
 sub run {
     my ($self, $s) = @_;
     if ((any { $s->[0] eq $_ } qw(use no)) &&
         scalar(@$s) > 3 && $s->[1] eq 'if') {
-        my ($version) = $s->[2] =~ /^(\d.*)$/o;
+        my ($version) = $s->[2] =~ $vre;
         $version //= '';
         my $voffset = $version ? 3 : 2;
         my ($depth, $index) = (0, 0);
@@ -62,7 +62,7 @@ Petr Šabata <contyk@redhat.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015 Petr Šabata
+Copyright (c) 2014-2016 Petr Šabata
 
 See LICENSE for licensing details.
 
