@@ -1,9 +1,9 @@
 package Tangerine::hook::moduleload;
-$Tangerine::hook::moduleload::VERSION = '0.19';
+$Tangerine::hook::moduleload::VERSION = '0.20';
 use strict;
 use warnings;
 use parent 'Tangerine::Hook';
-use List::MoreUtils qw(any);
+use List::Util 1.33 qw(any);
 use Tangerine::HookData;
 use Tangerine::Utils qw(stripquotelike);
 
@@ -57,7 +57,7 @@ Petr Šabata <contyk@redhat.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2015 Petr Šabata
+Copyright (c) 2015-2016 Petr Šabata
 
 See LICENSE for licensing details.
 
