@@ -1,10 +1,10 @@
 package Tangerine::hook::moduleruntime;
-$Tangerine::hook::moduleruntime::VERSION = '0.19';
+$Tangerine::hook::moduleruntime::VERSION = '0.20';
 use 5.010;
 use strict;
 use warnings;
 use parent 'Tangerine::Hook';
-use List::MoreUtils qw(any none);
+use List::Util 1.33 qw(any none);
 use Tangerine::HookData;
 use Tangerine::Occurence;
 use Tangerine::Utils qw(stripquotelike);
@@ -68,7 +68,7 @@ Petr Šabata <contyk@redhat.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2015 Petr Šabata
+Copyright (c) 2015-2016 Petr Šabata
 
 See LICENSE for licensing details.
 
