@@ -1,10 +1,10 @@
 package Tangerine::hook::mooselike;
-$Tangerine::hook::mooselike::VERSION = '0.19';
+$Tangerine::hook::mooselike::VERSION = '0.20';
 use 5.010;
 use strict;
 use warnings;
 use parent 'Tangerine::Hook';
-use List::MoreUtils qw(any none);
+use List::Util 1.33 qw(any none);
 use Tangerine::Hook;
 use Tangerine::HookData;
 use Tangerine::Utils qw(stripquotelike);
@@ -12,7 +12,8 @@ use Tangerine::Utils qw(stripquotelike);
 sub run {
     my ($self, $s) = @_;
     if ($self->type eq 'compile' && $s->[0] eq 'use' &&
-        scalar(@$s) > 1 && (any { $s->[1] eq $_ } qw(Moose Mouse Moo Mo))) {
+        scalar(@$s) > 1 && (any { $s->[1] eq $_ }
+        qw(Moose Mouse Moo Mo Role::Tiny::With))) {
         return Tangerine::HookData->new(
                 hooks => [
                     Tangerine::hook::mooselike->new(type => 'runtime'),
@@ -36,8 +37,8 @@ sub run {
             } else {
                 next unless $last;
                 $modules{$last} = $+{version} if
-                    $s->[$i] =~ /^\{.*-version\s*?(=>|,)\s*?((qq?\s*?[^\w]\s*)|'|")?v?
-                        (?<version>\d+?(\.\d+)*)((\s*?[^\w])|'|")?.*\}\s*$/xso;
+                    $s->[$i] =~ /^\{.*-version\s*?(?:=>|,)\s*?(?:(?:qq?\s*?[^\w]\s*)|'|")?v?
+                        (?<version>\d+?(?:\.\d+)*)(?:(?:\s*?[^\w])|'|")?.*\}\s*$/xso;
                 $last = undef;
             }
         }
@@ -70,11 +71,12 @@ checks for C<extends> and C<with> statements
 This hook catches various Moose-like modules and watches for their
 specific module-loading keywords, such as C<extends> and C<with>.
 
-Currently this hook knows about L<Moose>, L<Mouse>, L<Moo> and L<Mo>.
+Currently this hook knows about L<Moose>, L<Mouse>, L<Moo>, L<Mo> and
+L<Role::Tiny::With>.
 
 =head1 SEE ALSO
 
-L<Tangerine>, L<Moose>, L<Mouse>, L<Moo>, L<Mo>
+L<Tangerine>, L<Moose>, L<Mouse>, L<Moo>, L<Mo>, L<Role::Tiny::With>
 
 =head1 AUTHOR
 
@@ -82,7 +84,7 @@ Petr Šabata <contyk@redhat.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015 Petr Šabata
+Copyright (c) 2014-2016 Petr Šabata
 
 See LICENSE for licensing details.
 
