@@ -1,5 +1,5 @@
 package Tangerine::hook::require;
-$Tangerine::hook::require::VERSION = '0.19';
+$Tangerine::hook::require::VERSION = '0.20';
 use strict;
 use warnings;
 use parent 'Tangerine::Hook';
@@ -13,7 +13,7 @@ sub run {
         my $module = $s->[1];
         return Tangerine::HookData->new(
             modules => { $module => Tangerine::Occurence->new },
-            ) unless $module =~ /^v?5(\..*)?$/;
+            ) unless $module =~ /^v?5(?:\..*)?$/;
     }
     return;
 }
@@ -44,7 +44,7 @@ Petr Šabata <contyk@redhat.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015 Petr Šabata
+Copyright (c) 2014-2016 Petr Šabata
 
 See LICENSE for licensing details.
 
