@@ -1,9 +1,9 @@
 package Tangerine::hook::testloading;
-$Tangerine::hook::testloading::VERSION = '0.19';
+$Tangerine::hook::testloading::VERSION = '0.20';
 use strict;
 use warnings;
 use parent 'Tangerine::Hook';
-use List::MoreUtils qw/any/;
+use List::Util 1.33 qw(any);
 use Tangerine::HookData;
 use Tangerine::Occurence;
 use Tangerine::Utils qw(stripquotelike);
@@ -54,7 +54,7 @@ Petr Šabata <contyk@redhat.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015 Petr Šabata
+Copyright (c) 2014-2016 Petr Šabata
 
 See LICENSE for licensing details.
 
