@@ -1,10 +1,10 @@
 package Tangerine::hook::tests;
-$Tangerine::hook::tests::VERSION = '0.19';
+$Tangerine::hook::tests::VERSION = '0.20';
 use 5.010;
 use strict;
 use warnings;
 use parent 'Tangerine::Hook';
-use List::MoreUtils qw(any);
+use List::Util 1.33 qw(any);
 use Tangerine::Hook;
 use Tangerine::HookData;
 
@@ -56,7 +56,7 @@ Petr Šabata <contyk@redhat.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015 Petr Šabata
+Copyright (c) 2014-2016 Petr Šabata
 
 See LICENSE for licensing details.
 
