@@ -1,19 +1,20 @@
 package Tangerine::hook::use;
-$Tangerine::hook::use::VERSION = '0.19';
+$Tangerine::hook::use::VERSION = '0.20';
 use 5.010;
 use strict;
 use warnings;
 use parent 'Tangerine::Hook';
-use List::MoreUtils qw(any);
+use List::Util 1.33 qw(any);
 use Tangerine::HookData;
 use Tangerine::Occurence;
+use Tangerine::Utils qw($vre);
 
 sub run {
     my ($self, $s) = @_;
     if (scalar(@$s) > 1 && (any { $s->[0] eq $_ } qw(use no))) {
         return if $s->[1] eq ';';
         my $module = $s->[1];
-        my ($version) = $s->[2] && $s->[2] =~ /^(\d.*)$/o;
+        my ($version) = $s->[2] && $s->[2] =~ $vre;
         $version //= '';
         return Tangerine::HookData->new(
             modules => {
@@ -21,7 +22,7 @@ sub run {
                     version => $version,
                     ),
                 },
-            ) unless $module =~ /^v?5(\..*)?$/;
+            ) unless $module =~ /^v?5(?:\..*)?$/;
     }
     return;
 }
@@ -53,7 +54,7 @@ Petr Šabata <contyk@redhat.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015 Petr Šabata.
+Copyright (c) 2014-2016 Petr Šabata.
 
 See LICENSE for licensing details.
 
